==> appborg-0.0.9.tgz: package/js/lib/ABRouter.js <==
(function() {
  var ABRouter, ABSubprocessWrapper, EventEmitter, LineStream, async, decodeLine, encodeLine, spawn, _, _ref;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; }, __slice = Array.prototype.slice;
  EventEmitter = require('events').EventEmitter;
  spawn = require('child_process').spawn;
  LineStream = require('linestream');
  _ = require('underscore');
  async = require('async');
  _ref = require('./appborg_util'), encodeLine = _ref.encodeLine, decodeLine = _ref.decodeLine;
  ABSubprocessWrapper = (function() {
    __extends(ABSubprocessWrapper, EventEmitter);
    function ABSubprocessWrapper(_arg) {
      var ls, spawnArgs;
      this.router = _arg.router, this.name = _arg.name, this.debug = _arg.debug, spawnArgs = _arg.spawnArgs;
      ABSubprocessWrapper.__super__.constructor.call(this);
      this.p = this.subproc = spawn.apply(null, spawnArgs);
      this.stderr = this.p.stderr;
      ls = new LineStream(this.p.stdout);
      ls.on('data', __bind(function(line) {
        if (this.debug) {
          this.router.debugArr.push("---- [ABRouter] from subproc stdout ----\n" + (JSON.stringify(decodeLine(line))) + "\n" + (require('hexy').hexy(line)) + "\n---------------------------------");
        }
        return this.emit('event', decodeLine(line));
      }, this));
      this.p.on('exit', __bind(function() {
        var args;
        args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
        return this.emit.apply(this, ['exit'].concat(__slice.call(args)));
      }, this));
    }
    ABSubprocessWrapper.prototype.processEvent = function(event) {
      var data;
      data = encodeLine(event);
      this.p.stdin.write(data);
      if (this.debug) {
        return this.router.debugArr.push("---- [ABRouter] to subproc stdin ----\n" + (JSON.stringify(decodeLine(data))) + "\n" + (require('hexy').hexy(data)) + "\n---------------------------------");
      }
    };
    ABSubprocessWrapper.prototype.killDashNine = function(callback) {
      this.p.kill('SIGKILL');
      this.killed = true;
      return this.p.on('exit', callback);
    };
    return ABSubprocessWrapper;
  })();
  ABRouter = (function() {
    __extends(ABRouter, EventEmitter);
    function ABRouter(opt) {
      if (opt == null) {
        opt = {};
      }
      ABRouter.__super__.constructor.call(this);
      this.verbose = opt.verbose || false;
      this.debug = opt.debug || false;
      this.names = opt.name ? [opt.name] : opt.names ? opt.names : ["router"];
      this.counter = 0;
      this.wrappers = {};
      this.callbacks = {};
      this.debugArr = [];
    }
    ABRouter.prototype.killDashNine = function(callback) {
      var f;
      f = function(x, cb) {
        if (x.killDashNine) {
          return x.killDashNine(cb);
        } else {
          return cb(null);
        }
      };
      return async.forEach(_.values(this.wrappers), f, callback);
    };
    ABRouter.prototype.getDebugText = function() {
      return this.debugArr.join('\n\n');
    };
    ABRouter.prototype.spawn = function(command, args, opt) {
      var name, wrapper;
      if (opt == null) {
        opt = null;
      }
      name = (opt != null ? opt.name : void 0) || "subprocess";
      wrapper = new ABSubprocessWrapper({
        router: this,
        name: name,
        spawnArgs: [command, args, opt],
        debug: this.debug
      });
      this.wrappers[name] = wrapper;
      wrapper.on('event', __bind(function(e) {
        return this.processEvent(e);
      }, this));
      wrapper.on('exit', __bind(function() {
        if (this.verbose) {
          return console.log("[ABRouter][" + name + "] subprocess exited.");
        }
      }, this));
      wrapper.stderr.on('data', __bind(function(data) {
        if (this.verbose) {
          return console.log("[ABRouter][" + name + "] STDERR: " + (data.toString()));
        }
      }, this));
      return wrapper.subproc;
    };
    ABRouter.prototype.send = function() {
      var args, callback, dicts, info, method, opt, recipient, x, _i, _len;
      method = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
      dicts = [];
      callback = (function() {});
      for (_i = 0, _len = args.length; _i < _len; _i++) {
        x = args[_i];
        if (typeof x === 'function') {
          callback = x;
        } else {
          dicts.push(x);
        }
      }
      recipient = "subprocess";
      info = {};
      if (dicts.length === 1) {
        info = dicts[0];
      } else {
        opt = dicts[0], info = dicts[1];
        recipient = opt.to || recipient;
      }
      return this.sendTo(recipient, method, info, callback);
    };
    ABRouter.prototype.sendTo = function(dest, method, info, callback) {
      if (callback == null) {
        callback = function() {};
      }
      this.counter++;
      this.callbacks[this.counter] = callback;
      return this.processEvent({
        method: method,
        info: info,
        id: this.counter,
        from: this.names[0],
        to: dest
      });
    };
    ABRouter.prototype.processEvent = function(e) {
      var f;
      if (_.contains(this.names, e.to)) {
        if (e.method) {
          return this.emit('event', e);
        } else {
          this.emit('response', e);
          f = this.callbacks[e.id];
          if (f) {
            return f(e.error || null, e.result || {});
          }
        }
      } else {
        if (!this.wrappers[e.to]) {
          throw new Error("Unknown recipient: " + e.to);
        }
        return this.wrappers[e.to].processEvent(e);
      }
    };
    return ABRouter;
  })();
  module.exports = {
    ABRouter: ABRouter
  };
}).call(this);

==> appborg-0.0.16.tgz: package/js/lib/ABRouter.js <==
(function() {
  var ABRouter, ABSubprocessWrapper, EventEmitter, LineStream, async, decodeLine, encodeLine, spawn, _, _ref;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; }, __slice = Array.prototype.slice;
  EventEmitter = require('events').EventEmitter;
  spawn = require('child_process').spawn;
  LineStream = require('linestream');
  _ = require('underscore');
  async = require('async');
  _ref = require('./appborg_util'), encodeLine = _ref.encodeLine, decodeLine = _ref.decodeLine;
  ABSubprocessWrapper = (function() {
    __extends(ABSubprocessWrapper, EventEmitter);
    function ABSubprocessWrapper(_arg) {
      var ls, spawnArgs;
      this.router = _arg.router, this.name = _arg.name, this.debug = _arg.debug, spawnArgs = _arg.spawnArgs;
      ABSubprocessWrapper.__super__.constructor.call(this);
      this.p = this.subproc = spawn.apply(null, spawnArgs);
      this.stderr = this.p.stderr;
      ls = new LineStream(this.p.stdout);
      ls.on('data', __bind(function(line) {
        var decoded;
        decoded = null;
        try {
          decoded = decodeLine(line);
        } catch (e) {
          this.killDashNine();
          this.router.componentError(this, "Error decoding line " + (JSON.stringify(line)) + " from " + (JSON.stringify(this.name)));
        }
        if (decoded) {
          return this.emit('event', decoded);
        }
      }, this));
      this.p.on('exit', __bind(function() {
        var args;
        args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
        return this.emit.apply(this, ['exit'].concat(__slice.call(args)));
      }, this));
    }
    ABSubprocessWrapper.prototype.processEvent = function(event) {
      var data;
      data = encodeLine(event);
      this.p.stdin.write(data);
      if (this.debug) {
        return this.router.debugArr.push("---- [ABRouter] to subproc stdin ----\n" + (JSON.stringify(decodeLine(data))) + "\n" + (require('hexy').hexy(data)) + "\n---------------------------------");
      }
    };
    ABSubprocessWrapper.prototype.killDashNine = function(callback) {
      if (callback == null) {
        callback = (function() {});
      }
      this.p.kill('SIGKILL');
      this.killed = true;
      return this.p.on('exit', callback);
    };
    return ABSubprocessWrapper;
  })();
  ABRouter = (function() {
    __extends(ABRouter, EventEmitter);
    function ABRouter(opt) {
      if (opt == null) {
        opt = {};
      }
      ABRouter.__super__.constructor.call(this);
      this.verbose = opt.verbose || false;
      this.debug = opt.debug || false;
      this.names = opt.name ? [opt.name] : opt.names ? opt.names : ["router"];
      this.counter = 0;
      this.wrappers = {};
      this.callbacks = {};
      this.debugArr = [];
    }
    ABRouter.prototype.killDashNine = function(callback) {
      var f;
      f = function(x, cb) {
        if (x.killDashNine) {
          return x.killDashNine(cb);
        } else {
          return cb(null);
        }
      };
      return async.forEach(_.values(this.wrappers), f, callback);
    };
    ABRouter.prototype.getDebugText = function() {
      return this.debugArr.join('\n\n');
    };
    ABRouter.prototype.spawn = function(command, args, opt) {
      var name, wrapper;
      if (opt == null) {
        opt = null;
      }
      name = (opt != null ? opt.name : void 0) || "subprocess";
      wrapper = new ABSubprocessWrapper({
        router: this,
        name: name,
        spawnArgs: [command, args, opt],
        debug: this.debug
      });
      this.wrappers[name] = wrapper;
      wrapper.on('event', __bind(function(e) {
        return this.processEvent(e);
      }, this));
      wrapper.on('exit', __bind(function() {
        if (this.verbose) {
          return console.log("[ABRouter][" + name + "] subprocess exited.");
        }
      }, this));
      wrapper.stderr.on('data', __bind(function(data) {
        if (this.verbose) {
          return console.log("[ABRouter][" + name + "] STDERR: " + (data.toString()));
        }
      }, this));
      return wrapper.subproc;
    };
    ABRouter.prototype.send = function() {
      var args, callback, dicts, info, method, opt, recipient, x, _i, _len;
      method = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
      dicts = [];
      callback = (function() {});
      for (_i = 0, _len = args.length; _i < _len; _i++) {
        x = args[_i];
        if (typeof x === 'function') {
          callback = x;
        } else {
          dicts.push(x);
        }
      }
      recipient = "subprocess";
      info = {};
      if (dicts.length === 1) {
        info = dicts[0];
      } else {
        opt = dicts[0], info = dicts[1];
        recipient = opt.to || recipient;
      }
      return this.sendTo(recipient, method, info, callback);
    };
    ABRouter.prototype.sendTo = function(dest, method, info, callback) {
      if (callback == null) {
        callback = function() {};
      }
      this.counter++;
      this.callbacks[this.counter] = callback;
      return this.processEvent({
        method: method,
        info: info,
        id: this.counter,
        from: this.names[0],
        to: dest
      });
    };
    ABRouter.prototype.processEvent = function(e) {
      var f;
      if (_.contains(this.names, e.to)) {
        if (e.method) {
          return this.emit('event', e);
        } else {
          this.emit('response', e);
          f = this.callbacks[e.id];
          if (f) {
            return f(e.error || null, e.result || {});
          }
        }
      } else {
        if (!this.wrappers[e.to]) {
          throw new Error("Unknown recipient: " + e.to);
        }
        return this.wrappers[e.to].processEvent(e);
      }
    };
    ABRouter.prototype.componentError = function(component, message) {
      return this.emit('componentError', component, message);
    };
    return ABRouter;
  })();
  module.exports = {
    ABRouter: ABRouter
  };
}).call(this);
